==> appslandia-common-2.2-sources.jar: com/appslandia/common/base/PropertyConfig.java <==
// The MIT License (MIT)
// Copyright © 2015 AppsLandia. All rights reserved.

// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package com.appslandia.common.base;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
/**
*
* @author <a href="mailto:haducloc13@gmail.com">Loc Ha</a>
*
*/
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Reader;
import java.io.Writer;
import java.util.Collections;
import java.util.Enumeration;
import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.Map;
import java.util.Properties;
import java.util.Set;

import com.appslandia.common.utils.CharsetUtils;
import com.appslandia.common.utils.DateUtils;
import com.appslandia.common.utils.StringUtils;

/**
 *
 * @author <a href="mailto:haducloc13@gmail.com">Loc Ha</a>
 *
 */
public class PropertyConfig extends ConfigBase {
	private static final long serialVersionUID = 1L;

	public PropertyConfig() {
		super(new LinkedHashMap<>());
	}

	public PropertyConfig(Map<String, String> newMap) {
		super(newMap);
	}

	public void load(InputStream is) throws IOException {
		Properties props = new LinkedProperties();
		props.load(is);
		fromProperties(props);
	}

	public void load(Reader r) throws IOException {
		Properties props = new LinkedProperties();
		props.load(r);
		fromProperties(props);
	}

	public void load(File file) throws IOException {
		BufferedReader br = null;
		try {
			br = new BufferedReader(new InputStreamReader(new FileInputStream(file), CharsetUtils.UTF_8));
			load(br);
		} finally {
			if (br != null) {
				br.close();
			}
		}
	}

	public void load(String file) throws IOException {
		load(new File(file));
	}

	protected void fromProperties(Properties props) {
		for (Object k : props.keySet()) {
			String key = (String) k;
			String value = (String) props.get(key);

			if (!key.isEmpty()) {
				this.configs.put(key, !value.isEmpty() ? value : null);
			}
		}
	}

	public void store(File file, String comments) throws IOException {
		BufferedWriter bw = null;
		try {
			bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file), CharsetUtils.UTF_8));
			store(bw, comments);
		} finally {
			if (bw != null) {
				bw.close();
			}
		}
	}

	public void store(String file, String comments) throws IOException {
		store(new File(file), comments);
	}

	public void store(OutputStream os, String comments) throws IOException {
		toProperties().store(os, comments);
	}

	public void store(Writer w, String comments) throws IOException {
		toProperties().store(w, comments);
	}

	protected Properties toProperties() {
		Properties props = new LinkedProperties();
		for (Map.Entry<String, String> config : this.configs.entrySet()) {
			props.put(config.getKey(), config.getValue() != null ? config.getValue() : StringUtils.EMPTY_STRING);
		}
		return props;
	}

	@Override
	public String toString() {
		try {
			StringWriter out = new StringWriter();
			store(out, getClass().getName());
			return out.toString();
		} catch (IOException ex) {
			return null;
		}
	}

	public void put(String key, boolean value) {
		this.configs.put(key, Boolean.toString(value));
	}

	public void put(String key, int value) {
		this.configs.put(key, Integer.toString(value));
	}

	public void put(String key, long value) {
		this.configs.put(key, Long.toString(value));
	}

	public void put(String key, float value) {
		this.configs.put(key, Float.toString(value));
	}

	public void put(String key, double value) {
		this.configs.put(key, Double.toString(value));
	}

	public void put(String key, Boolean value) {
		this.configs.put(key, (value != null) ? value.toString() : null);
	}

	public void put(String key, Integer value) {
		this.configs.put(key, (value != null) ? value.toString() : null);
	}

	public void put(String key, Long value) {
		this.configs.put(key, (value != null) ? value.toString() : null);
	}

	public void put(String key, Float value) {
		this.configs.put(key, (value != null) ? value.toString() : null);
	}

	public void put(String key, Double value) {
		this.configs.put(key, (value != null) ? value.toString() : null);
	}

	public void put(String key, java.sql.Date value) {
		this.configs.put(key, (value != null) ? DateUtils.iso8601Date(value) : null);
	}

	public void put(String key, java.sql.Time value) {
		this.configs.put(key, (value != null) ? DateUtils.iso8601Time(value) : null);
	}

	public void put(String key, java.sql.Timestamp value) {
		this.configs.put(key, (value != null) ? DateUtils.iso8601DateTime(value) : null);
	}

	private static class LinkedProperties extends Properties {
		private static final long serialVersionUID = 1;

		final Set<Object> keys = new LinkedHashSet<>();

		@Override
		public Set<Object> keySet() {
			return this.keys;
		}

		@Override
		public Enumeration<Object> keys() {
			return Collections.enumeration(this.keys);
		}

		@Override
		public Object put(Object key, Object value) {
			this.keys.add(key);
			return super.put(key, value);
		}
	}
}

==> appslandia-common-2.4-sources.jar: com/appslandia/common/base/PropertyConfig.java <==
// The MIT License (MIT)
// Copyright © 2015 AppsLandia. All rights reserved.

// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:

// The above copyright notice and this permission notice shall be included in all
// copies or substantial portions of the Software.

// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

package com.appslandia.common.base;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileInputStream;
import java.io.FileOutputStream;
/**
*
* @author <a href="mailto:haducloc13@gmail.com">Loc Ha</a>
*
*/
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.io.OutputStream;
import java.io.OutputStreamWriter;
import java.io.Reader;
import java.io.Writer;
import java.util.Collections;
import java.util.Enumeration;
import java.util.LinkedHashMap;
import java.util.LinkedHashSet;
import java.util.Map;
import java.util.Properties;
import java.util.Set;

import com.appslandia.common.utils.CharsetUtils;
import com.appslandia.common.utils.StringUtils;

/**
 *
 * @author <a href="mailto:haducloc13@gmail.com">Loc Ha</a>
 *
 */
public class PropertyConfig extends ConfigBase {
	private static final long serialVersionUID = 1L;

	public PropertyConfig() {
		super(new LinkedHashMap<>());
	}

	public PropertyConfig(Map<String, String> newMap) {
		super(newMap);
	}

	public void load(InputStream is) throws IOException {
		Properties props = new LinkedProperties();
		props.load(is);
		fromProperties(props);
	}

	public void load(Reader r) throws IOException {
		Properties props = new LinkedProperties();
		props.load(r);
		fromProperties(props);
	}

	public void load(File file) throws IOException {
		BufferedReader br = null;
		try {
			br = new BufferedReader(new InputStreamReader(new FileInputStream(file), CharsetUtils.UTF_8));
			load(br);
		} finally {
			if (br != null) {
				br.close();
			}
		}
	}

	public void load(String file) throws IOException {
		load(new File(file));
	}

	protected void fromProperties(Properties props) {
		for (Object k : props.keySet()) {
			String key = (String) k;
			String value = (String) props.get(key);

			if (!key.isEmpty()) {
				this.props.put(key, !value.isEmpty() ? value : null);
			}
		}
	}

	public void store(File file, String comments) throws IOException {
		BufferedWriter bw = null;
		try {
			bw = new BufferedWriter(new OutputStreamWriter(new FileOutputStream(file), CharsetUtils.UTF_8));
			store(bw, comments);
		} finally {
			if (bw != null) {
				bw.close();
			}
		}
	}

	public void store(String file, String comments) throws IOException {
		store(new File(file), comments);
	}

	public void store(OutputStream os, String comments) throws IOException {
		toProperties().store(os, comments);
	}

	public void store(Writer w, String comments) throws IOException {
		toProperties().store(w, comments);
	}

	protected Properties toProperties() {
		Properties props = new LinkedProperties();
		for (Map.Entry<String, String> config : this.props.entrySet()) {
			props.put(config.getKey(), config.getValue() != null ? config.getValue() : StringUtils.EMPTY_STRING);
		}
		return props;
	}

	@Override
	public String toString() {
		try {
			StringWriter out = new StringWriter();
			store(out, getClass().getName());
			return out.toString();
		} catch (IOException ex) {
			return null;
		}
	}

	public PropertyConfig put(String key, String value) {
		return (PropertyConfig) super.put(key, value);
	}

	public PropertyConfig put(String key, boolean value) {
		return (PropertyConfig) super.put(key, value);
	}

	public PropertyConfig put(String key, int value) {
		return (PropertyConfig) super.put(key, value);
	}

	public PropertyConfig put(String key, long value) {
		return (PropertyConfig) super.put(key, value);
	}

	public PropertyConfig put(String key, float value) {
		return (PropertyConfig) super.put(key, value);
	}

	public PropertyConfig put(String key, double value) {
		return (PropertyConfig) super.put(key, value);
	}

	public PropertyConfig put(String key, Boolean value) {
		return (PropertyConfig) super.put(key, value);
	}

	public PropertyConfig put(String key, Integer value) {
		return (PropertyConfig) super.put(key, value);
	}

	public PropertyConfig put(String key, Long value) {
		return (PropertyConfig) super.put(key, value);
	}

	public PropertyConfig put(String key, Float value) {
		return (PropertyConfig) super.put(key, value);
	}

	public PropertyConfig put(String key, Double value) {
		return (PropertyConfig) super.put(key, value);
	}

	public PropertyConfig put(String key, java.sql.Date value) {
		return (PropertyConfig) super.put(key, value);
	}

	public PropertyConfig put(String key, java.sql.Time value) {
		return (PropertyConfig) super.put(key, value);
	}

	public PropertyConfig put(String key, java.sql.Timestamp value) {
		return (PropertyConfig) super.put(key, value);
	}

	private static class LinkedProperties extends Properties {
		private static final long serialVersionUID = 1;

		final Set<Object> keys = new LinkedHashSet<>();

		@Override
		public Set<Object> keySet() {
			return this.keys;
		}

		@Override
		public Enumeration<Object> keys() {
			return Collections.enumeration(this.keys);
		}

		@Override
		public Object put(Object key, Object value) {
			this.keys.add(key);
			return super.put(key, value);
		}
	}
}
